@@ -17,6 +17,7 @@ from hexathon import (
         )
 import sha3
 from funga.eth.signer import EIP155Signer
+from chainlib.settings import ChainSettings
 
 # local imports
 from chainlib.eth.address import AddressChecksum
@@ -35,10 +36,20 @@ from chainlib.eth.gas import (
         price,
         )
 import chainlib.eth.cli
+from chainlib.eth.cli.arg import (
+        Arg,
+        ArgFlag,
+        process_args,
+        )
+from chainlib.eth.cli.config import (
+        Config,
+        process_config,
+        )
+from chainlib.eth.cli.log import process_log
+from chainlib.eth.settings import process_settings
 
 BLOCK_SAMPLES = 10
 
-logging.basicConfig(level=logging.WARNING)
 logg = logging.getLogger()
 
 script_dir = os.path.dirname(os.path.realpath(__file__)) 
@@ -54,34 +65,37 @@ results_translation = {
         }
 
 
-arg_flags = chainlib.eth.cli.argflag_std_read
-argparser = chainlib.eth.cli.ArgumentParser(arg_flags)
+def process_config_local(config, arg, args, flags):
+    config.add(args.local, '_LOCAL', False)
+    config.add(args.long, '_LONG', False)
+    config.add(args.entry, '_ENTRY', False)
+    if config.get('_ENTRY') != None:
+        if config.get('_ENTRY') not in results_translation.keys():
+            raise ValueError('Unknown entry {}'.format(config.get('_ENTRY')))
+    return config
+
+arg_flags = ArgFlag()
+arg = Arg(arg_flags)
+flags = arg_flags.STD_READ | arg_flags.ENV
+
+argparser = chainlib.eth.cli.ArgumentParser()
+argparser = process_args(argparser, arg, flags)
 argparser.add_argument('--long', action='store_true', help='Calculate averages through sampling of blocks and txs')
 argparser.add_argument('--local', action='store_true', help='Include local info')
-argparser.add_positional('entry', required=False, help='Output single item')
+argparser.add_argument('entry', nargs='?', help='Output single item')
 args = argparser.parse_args()
 
-extra_args = {
-        'local': None,
-        'long': None,
-        'entry': None,
-        }
-config = chainlib.eth.cli.Config.from_args(args, arg_flags, extra_args=extra_args, default_config_dir=config_dir)
+logg = process_log(args, logg)
 
-if config.get('_ENTRY') != None:
-    if config.get('_ENTRY') not in results_translation.keys():
-        raise ValueError('Unknown entry {}'.format(config.get('_ENTRY')))
+config = Config()
+config = process_config(config, arg, args, flags)
+config = process_config_local(config, arg, args, flags)
+logg.debug('config loaded:\n{}'.format(config))
 
-rpc = chainlib.eth.cli.Rpc()
-conn = rpc.connect_by_config(config)
+settings = ChainSettings()
+settings = process_settings(settings, config)
+logg.debug('settings loaded:\n{}'.format(settings))
 
-token_symbol = 'eth'
-
-chain_spec = ChainSpec.from_chain_str(config.get('CHAIN_SPEC'))
-
-human = not config.true('_RAW')
-
-longmode = config.true('_LONG')
 
 def set_result(results, k, v, w=sys.stdout):
     kt = results_translation[k]
@@ -94,17 +108,16 @@ def set_result(results, k, v, w=sys.stdout):
 
 
 def main():
+    human = not config.true('_RAW')
     results = {}
 
-    o = network_id(id_generator=rpc.id_generator)
-    r = conn.do(o)
-    #if human:
-    #    n = format(n, ',')
+    o = network_id(id_generator=settings.get('RPC_ID_GENERATOR'))
+    r = settings.get('CONN').do(o)
     if set_result(results, 'network_id', r):
         return
 
-    o = block_latest(id_generator=rpc.id_generator)
-    r = conn.do(o)
+    o = block_latest(id_generator=settings.get('RPC_ID_GENERATOR'))
+    r = settings.get('CONN').do(o)
     try:
         n = int(r, 16)
     except ValueError:
@@ -115,17 +128,17 @@ def main():
     if set_result(results, 'block', n):
         return
 
-    o = block_by_number(first_block_number, False, id_generator=rpc.id_generator)
-    r = conn.do(o)
+    o = block_by_number(first_block_number, False, id_generator=settings.get('RPC_ID_GENERATOR'))
+    r = settings.get('CONN').do(o)
     last_block = Block(r)
     last_timestamp = last_block.timestamp
 
-    if longmode:
+    if config.true('_LONG'):
         aggr_time = 0.0
         aggr_gas = 0
         for i in range(BLOCK_SAMPLES): 
-            o = block_by_number(first_block_number-i, False, id_generator=rpc.id_generator)
-            r = conn.do(o)
+            o = block_by_number(first_block_number-i, False, id_generator=settings.get('RPC_ID_GENERATOR'))
+            r = settings.get('CONN').do(o)
             block = Block(r)
             aggr_time += last_block.timestamp - block.timestamp
         
@@ -144,8 +157,8 @@ def main():
         if set_result(results, 'block_time', aggr_time / BLOCK_SAMPLES):
             return
 
-    o = price(id_generator=rpc.id_generator)
-    r = conn.do(o)
+    o = price(id_generator=settings.get('RPC_ID_GENERATOR'))
+    r = settings.get('CONN').do(o)
     n = int(r, 16)
     if human:
         n = format(n, ',')
@@ -154,7 +167,7 @@ def main():
 
     if config.get('_LOCAL'):
         o = syncing()
-        r = conn.do(o)
+        r = settings.get('CONN').do(o)
         if set_result(results, 'syncing', r):
             return
 
